@@ -1,13 +1,12 @@
 # coding: utf-8
-from urllib.parse import quote
 
+# DJANGO IMPORTS
 from django import template
-from django.template import TemplateSyntaxError
-from django.utils.safestring import mark_safe
+from django.utils.http import urlquote
 
+# FILEBROWSER IMPORTS
 from filebrowser.settings import EXTENSIONS, SELECT_FORMATS
 
-
 register = template.Library()
 
 
@@ -54,6 +53,7 @@ def get_query_string(p, new_params=None, remove=None):
         remove = []
     for r in remove:
         for k in list(p):
+            #if k.startswith(r):
             if k == r:
                 del p[k]
     for k, v in new_params.items():
@@ -61,7 +61,7 @@ def get_query_string(p, new_params=None, remove=None):
             del p[k]
         elif v is not None:
             p[k] = v
-    return '?' + '&'.join([u'%s=%s' % (quote(k), quote(v)) for k, v in p.items()])
+    return '?' + '&'.join([u'%s=%s' % (urlquote(k), urlquote(v)) for k, v in p.items()])
 
 
 def string_to_dict(string):
@@ -151,12 +151,15 @@ def get_file_extensions(qs):
     else:
         for k, v in EXTENSIONS.items():
             for item in v:
-                if item:
-                    extensions.append(item)
-    return mark_safe(extensions)
+                if item: extensions.append(item)
+    return extensions
+
+register.simple_tag(get_file_extensions)
 
 
-# Django 1.9 auto escapes simple_tag unless marked as safe
-@register.simple_tag(name='get_file_extensions')
-def get_file_extensions_safe(qs):
-    return mark_safe(get_file_extensions(qs))
+try:  # Import cycle from future for django 1.7+
+    from django.templatetags.future import cycle
+except ImportError:
+    pass
+else:
+    register.tag(cycle)
